/* ***** BEGIN LICENSE BLOCK *****
 * This file is part of Natron <http://www.natron.fr/>,
 * Copyright (C) 2016 INRIA and Alexandre Gauthier-Foichat
 *
 * Natron is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Natron is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Natron.  If not, see <http://www.gnu.org/licenses/gpl-2.0.html>
 * ***** END LICENSE BLOCK ***** */

// ***** BEGIN PYTHON BLOCK *****
// from <https://docs.python.org/3/c-api/intro.html#include-files>:
// "Since Python may define some pre-processor definitions which affect the standard headers on some systems, you must include Python.h before any standard headers are included."
#include <Python.h>
// ***** END PYTHON BLOCK *****

#include "TextureRect.h"

#include <cassert>
#include <stdexcept>

#include "Engine/RectI.h"

NATRON_NAMESPACE_ENTER;

bool TextureRect::intersect(const RectI & r,
                            RectI* intersection) const
{
    if ( isNull() || r.isNull() ) {
        return false;
    }

    if ( (x1 > r.x2) || (r.x1 > x2) || (y1 > r.y2) || (r.y1 > y2) ) {
        return false;
    }

    intersection->x1 = std::max(x1,r.x1);
    intersection->x2 = std::min(x2,r.x2);
    intersection->y1 = std::max(y1,r.y1);
    intersection->y2 = std::min(y2,r.y2);

    return true;
}

NATRON_NAMESPACE_EXIT;
